@@ -2,5 +2,5 @@ from starrydb.starrydb import StarryServer, StarryClient
 __author__ = "Luo Xi <rossi913@163.com>"
 __license__ = "MIT License"
 
-__all__ = ['StarryServer', 'StarryClient']
+__all__ = ['StarryServer', 'StarryClient', 'StarryError']
 
